==> powertools-1.0.tar.bz2: lwp_si_packages/phplist/2.7.2/dAPI.py <==
                
import deployables_lib as dl
import urlparse
import shutil
import os
import re
dl.load_msgs_module("phplist-2.7.2", symtab = globals())

dir_moves = [('phplist-2.7.2/public_html', ''),
             ('phplist-2.7.2', 'docs')]
file_mods = [{'path' : 'tmp/', 'create' : '', 'delete' : ''},
             {'path' : '.htaccess', 'delete' : ''}]
secure_files = [('lists/config/config.php', 0600, 0600),
                ('tmp', 0700, 0700)]
instance_patches = []

pat = "^\s*\$(?P<key>\S+\w)\s*=\s*(?P<value>['\"].*['\"])\s*;\s*"
sub = "$%(key)s = %(value)s;"

pat2 = """^\s*define\s*\(("|')(?P<key>[^'"]+)("|')\s*,\s*(?P<value>.*)\)\s*;(?P<comment>\s*/\*.*)?$"""
sub2 = "define('%(key)s',%(value)s);%(comment)s"

hack_pat = '^(?P<key>\s*)(?P<value>if \(\$_SERVER\["USER"\]\) {)'
hack_pat2 = '^(?P<key>\s*)(?P<value>if \(0\) { # REMOVE THIS)'
hack_sub = '%(key)s%(value)s'
hack_vars = [('', 'if (0) { # REMOVE THIS')]
hack_vars2 =  [('', 'if ($_SERVER["USER"]) {')]

def install(site, site_conf, instance_conf, msgs):

    actions = ['resolve_location', 'check_disk_quota', 'check_mysql_enabled',
               'check_pass', 'check_install_loc_owner', '']
    args_dict = {}
    dl.do_install_actions(site, site_conf, instance_conf, msgs,
                          globals(), actions, args_dict)
    if msgs.get_severity() != msgs.ERROR:
       pageroot = urlparse.urlsplit(instance_conf['url_loc'])[2] + '/lists'
       tmp_dir = (instance_conf['install_loc'] + '/tmp', dl.MODSTR_JAIL)
       # XXX Need to update website, domain in phplist_config table
       sql_stmts = ["UPDATE phplist_admin SET loginname = '%s', email = '%s'," \
                    " password = '%s'""" % \
                    (instance_conf['instance_admin'],
                    instance_conf['instance_admin_email'],
                    instance_conf['instance_pass1']),
                   "UPDATE phplist_config SET value = '%s' WHERE "
                   "item = 'website'" % \
       urlparse.urlsplit(instance_conf['url_loc'])[1]]
       vars = [('database_user', site_conf['mysql']['dbaseadmin']),
               ('database_password', instance_conf['dbpass']),
               ('database_host', dl.get_mysql_host(site)),
               ('database_name', instance_conf['dbname']),
               ('tmpdir', tmp_dir),
               ('attachment_repository', tmp_dir),
               ('check_for_host', 0),
               ('pageroot', pageroot)]
       vars2 = [('ENCRYPTPASSWORD', 1), ('TEST', 0)]
       actions = ['db_create', 'db_probe', 'archive_unpack','handle_security_mode',
                  'set_php_cgi', 'edit_conf_file']

       args_dict = {
           'archive_unpack':       {'dir_moves': dir_moves},
           'handle_security_mode': {'files': secure_files},
           'edit_conf_file':  { 'file': 'lists/config/config.php',
                                'lang': 'php', 'pat': pat, 'sub': sub,
                                'vars': vars },
                    }
       dl.do_install_actions(site, site_conf, instance_conf, msgs,
                             globals(), actions, args_dict)

       actions = ['edit_conf_file','exec_php_script', 'edit_conf_file1','exec_mysql', 'handle_security_mode',
                  'access_url']

       args_dict = {
           'edit_conf_file' : { 'file' : 'lists/admin/index.php',
                                'lang' : 'apache_config', 'pat' : hack_pat,
                                'sub' : hack_sub, 'vars' : hack_vars
                                },
           'exec_php_script': {'script' : 'lists/admin/index.php',
                               'args' : {'page' : 'initialise'
                                         },
                               'success_re' : '.*Success:'},
           'edit_conf_file1' : { 'file' : 'lists/admin/index.php',
                                 'lang' : 'apache_config', 'pat' : hack_pat2,
                                 'sub' : hack_sub, 'vars' : hack_vars2
                               },
           'exec_mysql' : {'sql' : sql_stmts},
           'handle_security_mode': {'files': secure_files}
                   }

       dl.do_install_actions(site, site_conf, instance_conf, msgs,
                             globals(), actions, args_dict)

                                                                                                                                            
               
def reconfigure(context, site, site_conf, old_site_conf, instance_conf,
                old_instance_conf, msgs):

    actions = ['handle_url_loc', 'resolve_location', 'require_url_loc', '',
               'archive_unpack', 'handle_username_change', 'handle_db_changes']
    args_dict = {
            'archive_unpack': {'dir_moves': dir_moves,
			       'fileinfo' : {'excluded_files' :
					     ['lists/config/config.php']}},
            }
    if context != dl.CONTEXT_SITE_EDIT and instance_conf.get('dbpass'):
        actions.insert(0, 'db_probe')
        args_dict['db_probe'] = {'use_old' : 1}
    dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                              instance_conf, old_instance_conf, msgs,
                              globals(), actions, args_dict)
    if msgs.get_severity() != msgs.ERROR:
        old_tmp = "%s%s" % (dl.site_fs_jail(site, old_site_conf),
                             instance_conf['install_loc'] + '/tmp')
        new_tmp = "%s%s" % (dl.site_fs_jail(site, site_conf),
                             instance_conf['install_loc'] + '/tmp')        
        new_pageroot = urlparse.urlsplit(instance_conf['url_loc'])[2] + '/lists'
        old_pageroot = urlparse.urlsplit(instance_conf['url_loc'])[2] + '/lists'
        vars = [('tmpdir', new_tmp, old_tmp),
                ('pageroot', new_pageroot, old_pageroot),
                ('attachment_repository', new_tmp, old_tmp)]
        if dl.mysql_installed(site_conf, old_site_conf):
            vars.extend([('database_user', site_conf['mysql']['dbaseadmin'],
                          old_site_conf['mysql']['dbaseadmin']),
                         ('database_name', instance_conf['dbname'],
                          old_instance_conf['dbname'])])
        if context != dl.CONTEXT_SITE_EDIT:
            # We will only change the mysql host if a user specifically
            # invokes reconfigure; we don't want this change to happen
            # during upgradeupgrade, when all the sites are edited, but the
            # mysql.sock file hasn't moved yet.
            vars.append(('database_host', dl.get_mysql_host(site)))
            if instance_conf.get('dbpass'):
                vars.append(('database_password', instance_conf['dbpass']))
        actions2 = ['edit_conf_file', 'apply_patch', 'handle_security_mode']
        args_dict = {
            'handle_security_mode': { 'files': secure_files },
            'edit_conf_file' : {'file' : 'lists/config/config.php', 'lang' : 'php',
                                'pat' : pat, 'sub' : sub, 'vars' : vars},
            'apply_patch' : {'patches' : instance_patches}
            }
        dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                                  instance_conf, old_instance_conf, msgs,
                                  globals(), actions2, args_dict)
        
def remove(site, site_conf, instance_conf, msgs):
    dl.db_drop(site, site_conf, instance_conf)
    dl.install_loc_cleanup(site, site_conf, instance_conf, dir_moves,
                           file_mods = file_mods)
    
def get_instance_configuration(context, site, site_conf, instance_conf,
                               old_instance_conf, locale, msgs):
    instance = dl.dsp_create_instance(instance_conf['shortname'],
                                      instance_conf['version'])
    if context == dl.CONTEXT_UPGRADE:
        #and \
        #instance_conf['version'] != old_instance_conf['version']:
        # We need to be able to log in so that we can do the
        # upgrade, so expose these options.
        for option in instance['options']:
            if option['name'] == 'instance_admin' or \
               option['name'] == 'instance_pass1':
                option['upgrade'] = 1
    dl.dsp_fill_instance(context, instance, site, site_conf,
                         instance_conf, old_instance_conf,
                         ['dbname', 'username', 'url_net', 'url_path',
                          'domain_to_path', 'instance_admin_email'])
    dl.enable_patches(instance, instance_patches)
        
    return instance

def regression_test(action, index, test_data):
    if 'url_loc_modified' not in test_data:
        test_data['url_loc'] = test_data['url_loc'] + '/lists/admin/'
        test_data['url_loc_modified'] = 1
    return dl.regression_check_index(action, index, test_data,
                                     'This document requires you to log in')

def upgrade(site, site_conf, instance_conf, old_instance_conf, msgs):
    if old_instance_conf['shortname'] == 'phplist' and \
       old_instance_conf['version'] == '2.6.2':


        instance_conf['syncfs'] = '1'
        instance_conf['overwritefiles'] = '1'
        
        if not instance_conf.get('instance_admin'):
                    msgs.append((ERROR, ADMIN_EMPTY, None))
                    
        elif not instance_conf.get('instance_pass1'):
                    msgs.append((ERROR, PASSWORD_EMPTY, None))

        if msgs.get_severity() != msgs.ERROR:
            
            actions = ['exec_php_script']
            args_dict = {
                'exec_php_script' :{
                                     'script' : 'lists/admin/index.php',
                                     'args' : { 'login' : instance_conf['instance_admin'],
                                                'password' : instance_conf['instance_pass1']
                                               },
                                     'failure_re' : '.*invalid password'
                                     },
                        }
            dl.do_upgrade_actions(site, site_conf, instance_conf,
                              old_instance_conf, msgs,
                              globals(), actions, args_dict)
            
            if msgs.get_severity() == msgs.ERROR:
                msgs.append((ERROR, PASSWORD_MISMATCH, None))
            else:    
                actions = ['do_backup', '',
                           'archive_unpack', 'edit_conf_file','exec_php_script',
                           'edit_conf_file2', 'handle_security_mode']
            
                args_dict = {
                    'archive_unpack': { 'dir_moves' : dir_moves,
                                        'patches' : instance_patches,
                                        'fileinfo' :
                                        {'excluded_files' : ['lists/config/config.php']}},
                    'edit_conf_file' : { 'file' : 'lists/admin/index.php',
                                         'lang' : 'apache_config', 'pat' : hack_pat,
                                         'sub' : hack_sub, 'vars' : hack_vars
                                         },
                    'exec_php_script' :{
                                      'script' : 'lists/admin/index.php',
                                      'args' : { 'login' : instance_conf['instance_admin'],
                                                 'password' : instance_conf['instance_pass1'],
                                                 'page' : 'upgrade',
                                                 'doit' : 'yes'
                                                 
                                                },
                                      'success_re' : '.*Information: Success'
                                     },
                    'edit_conf_file2' : { 'file' : 'lists/admin/index.php',
                                          'lang' : 'apache_config', 'pat' : hack_pat2,
                                          'sub' : hack_sub, 'vars' : hack_vars2
                                          },
                    'handle_security_mode' : { 'files': ['lists/config/config.php'] }
                    }
            
                dl.do_upgrade_actions(site, site_conf, instance_conf,
                                      old_instance_conf, msgs,
                                      globals(), actions, args_dict)

==> powertools-1.0.1.tar.bz2: lwp_si_packages/phplist/2.10.4/dAPI.py <==
import deployables_lib as dl
import urlparse
import shutil
import os
import re
dl.load_msgs_module("phplist-2.10.4", symtab = globals())

dir_moves = [('phplist-2.10.4/public_html', ''),
             ('phplist-2.10.4', 'docs')]
file_mods = [{'path' : 'tmp/', 'create' : '', 'delete' : ''},
             {'path' : '.htaccess', 'delete' : ''}]
secure_files = [('lists/config/config.php', 0600, 0600),
                ('tmp', 0700, 0700)]
instance_patches = []

pat = "^\s*\$(?P<key>\S+\w)\s*=\s*(?P<value>['\"].*['\"])\s*;\s*"
sub = "$%(key)s = %(value)s;"

pat2 = """^\s*define\s*\(("|')(?P<key>[^'"]+)("|')\s*,\s*(?P<value>.*)\)\s*;(?P<comment>\s*/\*.*)?$"""
sub2 = "define('%(key)s',%(value)s);%(comment)s"

hack_pat = '^(?P<key>\s*)(?P<value>if \(\$_SERVER\["USER"\]\) {)'
hack_pat2 = '^(?P<key>\s*)(?P<value>if \(0\) { # REMOVE THIS)'
hack_sub = '%(key)s%(value)s'
hack_vars = [('', 'if (0) { # REMOVE THIS')]
hack_vars2 =  [('', 'if ($_SERVER["USER"]) {')]


def install(site, site_conf, instance_conf, msgs):

    actions = ['resolve_location', 'check_disk_quota', 'check_mysql_enabled',
               'check_pass', 'check_install_loc_owner', '']
    args_dict = {}
    dl.do_install_actions(site, site_conf, instance_conf, msgs,
                          globals(), actions, args_dict)
    if msgs.get_severity() != msgs.ERROR:
       pageroot = urlparse.urlsplit(instance_conf['url_loc'])[2] + '/lists'
       tmp_dir = (instance_conf['install_loc'] + '/tmp', dl.MODSTR_JAIL)
       # XXX Need to update website, domain in phplist_config table
       sql_stmts = ["UPDATE phplist_admin SET loginname = '%s', email = '%s'," \
                    " password = '%s'""" % \
                    (instance_conf['instance_admin'],
                    instance_conf['instance_admin_email'],
                    instance_conf['instance_pass1']),
                   "UPDATE phplist_config SET value = '%s' WHERE "
                   "item = 'website'" % \
       urlparse.urlsplit(instance_conf['url_loc'])[1]]
       vars = [('database_user', site_conf['mysql']['dbaseadmin']),
               ('database_password', instance_conf['dbpass']),
               ('database_host', dl.get_mysql_host(site)),
               ('database_name', instance_conf['dbname']),
               ('tmpdir', tmp_dir),
               ('attachment_repository', tmp_dir),
               ('check_for_host', 0),
               ('pageroot', pageroot)]
       vars2 = [('ENCRYPTPASSWORD', 1), ('TEST', 0)]
       actions = ['db_create', 'db_probe', 'archive_unpack','handle_security_mode',
                  'set_php_cgi', 'edit_conf_file']

       args_dict = {
           'archive_unpack':       {'dir_moves': dir_moves},
           'handle_security_mode': {'files': secure_files},
           'edit_conf_file':  { 'file': 'lists/config/config.php',
                                'lang': 'php', 'pat': pat, 'sub': sub,
                                'vars': vars },
                    }
       dl.do_install_actions(site, site_conf, instance_conf, msgs,
                             globals(), actions, args_dict)

       actions = ['edit_conf_file','exec_php_script', 'edit_conf_file1','exec_mysql', 'handle_security_mode',
                  'access_url']

       args_dict = {
           'edit_conf_file' : { 'file' : 'lists/admin/index.php',
                                'lang' : 'apache_config', 'pat' : hack_pat,
                                'sub' : hack_sub, 'vars' : hack_vars
                                },
           'exec_php_script': {'script' : 'lists/admin/index.php',
                               'args' : {'page' : 'initialise'
                                         },
                               'success_re' : '.*Success:'},
           'edit_conf_file1' : { 'file' : 'lists/admin/index.php',
                                 'lang' : 'apache_config', 'pat' : hack_pat2,
                                 'sub' : hack_sub, 'vars' : hack_vars2
                               },
           'exec_mysql' : {'sql' : sql_stmts},
           'handle_security_mode': {'files': secure_files}
                   }

       dl.do_install_actions(site, site_conf, instance_conf, msgs,
                             globals(), actions, args_dict)

def upgrade(site, site_conf, instance_conf, old_instance_conf, msgs):
    if old_instance_conf['shortname'] == 'phplist':
       if old_instance_conf['version'] == '2.7.2':

        instance_conf['syncfs'] = '1'
        instance_conf['overwritefiles'] = '1'
        instance_conf['browser_conf']={'REMOTE_ADDR':'1.2.3.4'}
        
        if not instance_conf.get('instance_admin'):
                    msgs.append((ERROR, ADMIN_EMPTY, None))
                    
        elif not instance_conf.get('instance_pass1'):
                    msgs.append((ERROR, PASSWORD_EMPTY, None))

        if msgs.get_severity() != msgs.ERROR:
            
            actions = ['exec_php_script']
            args_dict = {
                'exec_php_script' :{
                                     'script' : 'lists/admin/index.php',
                                     'args' : { 'login' : instance_conf['instance_admin'],
                                                'password' : instance_conf['instance_pass1']
                                               },
                                     'failure_re' : '.*invalid password'
                                     },
                        }
            dl.do_upgrade_actions(site, site_conf, instance_conf,
                              old_instance_conf, msgs,
                              globals(), actions, args_dict)
            
            if msgs.get_severity() == msgs.ERROR:
                msgs.append((ERROR, PASSWORD_MISMATCH, None))
            else:
                uid, gid = dl.get_site_user_ids(site, instance_conf['username'])
                path = dl.site_fs(site) + old_instance_conf['install_loc'] + '/lists/config/config.php'
                conf_data = dl.readfile(path, uid, gid)
                i = 0
                dbpassword = dbdatabase = ""
                p = re.compile("\$database_\w*\s=\s\'.*\';")
                for line in p.findall(conf_data):
                        vals=re.sub("^\$\w*_\w*\s=","",line)
                        val=re.sub("^\s\'","",vals )
                        va=re.sub("\';$","",val )
                        if i == 1:
                                dbdatabase = va
                        elif i == 3:
                                dbpassword = va
                        i=i+1    
                path1 = re.sub("/var/www/html","",old_instance_conf['install_loc'])
                variables = [('database_user', site_conf['mysql']['dbaseadmin']),
                                ('database_password', dbpassword),
                                ('database_host', dl.get_mysql_host(site)),
                                ('database_name', dbdatabase),
                                ('pageroot', path1 + '/lists') ]
                actions = ['do_backup', '',
                           'archive_unpack', 'edit_conf_file','exec_php_script',
                           'handle_security_mode']
            
                args_dict = {
                    'archive_unpack': { 'dir_moves' : dir_moves,
                                        'patches' : instance_patches
                                      },
                    'edit_conf_file' : { 'file' : 'lists/config/config.php',
                                         'lang' : 'php', 'pat' : pat,
                                         'sub' : sub, 'vars' : variables
                                         },
                    'exec_php_script' :{
                                      'script' : 'lists/admin/index.php',
                                      'args' : { 'login' : instance_conf['instance_admin'],
                                                 'password' : instance_conf['instance_pass1'],
                                                 'page' : 'upgrade',
                                                 'doit' : 'yes'
                                                },
                                      'success_re' : '.*Success'
                                     },
                    'handle_security_mode' : { 'files': ['lists/config/config.php'] }
                    }
            
                dl.do_upgrade_actions(site, site_conf, instance_conf,
                                      old_instance_conf, msgs,
                                      globals(), actions, args_dict)
               
def reconfigure(context, site, site_conf, old_site_conf, instance_conf,
                old_instance_conf, msgs):

    actions = ['handle_url_loc', 'resolve_location', 'require_url_loc', '',
               'archive_unpack', 'handle_username_change', 'handle_db_changes']
    args_dict = {
            'archive_unpack': {'dir_moves': dir_moves,
            'fileinfo' :      {'excluded_files' : ['lists/config/config.php']}
                              },
                }
    if context != dl.CONTEXT_SITE_EDIT and instance_conf.get('dbpass'):
        actions.insert(0, 'db_probe')
        args_dict['db_probe'] = {'use_old' : 1}
    dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                              instance_conf, old_instance_conf, msgs,
                              globals(), actions, args_dict)
    if msgs.get_severity() != msgs.ERROR:
        old_tmp = "%s%s" % (dl.site_fs_jail(site, old_site_conf),
                             instance_conf['install_loc'] + '/tmp')
        new_tmp = "%s%s" % (dl.site_fs_jail(site, site_conf),
                             instance_conf['install_loc'] + '/tmp')
        new_pageroot = urlparse.urlsplit(instance_conf['url_loc'])[2] + '/lists'
        old_pageroot = urlparse.urlsplit(instance_conf['url_loc'])[2] + '/lists'
        vars = [('tmpdir', new_tmp, old_tmp),
                ('pageroot', new_pageroot, old_pageroot),
                ('attachment_repository', new_tmp, old_tmp)]
        if dl.mysql_installed(site_conf, old_site_conf):
            vars.extend([('database_user', site_conf['mysql']['dbaseadmin'],
                          old_site_conf['mysql']['dbaseadmin']),
                         ('database_name', instance_conf['dbname'],
                          old_instance_conf['dbname'])])
        if context != dl.CONTEXT_SITE_EDIT:
            # We will only change the mysql host if a user specifically
            # invokes reconfigure; we don't want this change to happen
            # during upgradeupgrade, when all the sites are edited, but the
            # mysql.sock file hasn't moved yet.
            vars.append(('database_host', dl.get_mysql_host(site)))
            if instance_conf.get('dbpass'):
                vars.append(('database_password', instance_conf['dbpass']))
        actions2 = ['edit_conf_file', 'apply_patch', 'handle_security_mode']
        args_dict = {
            'handle_security_mode': { 'files': secure_files },
            'edit_conf_file' : {'file' : 'lists/config/config.php', 'lang' : 'php',
                                'pat' : pat, 'sub' : sub, 'vars' : vars},
            'apply_patch' : {'patches' : instance_patches}
            }
        dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                                  instance_conf, old_instance_conf, msgs,
                                  globals(), actions2, args_dict)
        
def remove(site, site_conf, instance_conf, msgs):
    dl.db_drop(site, site_conf, instance_conf)
    dl.install_loc_cleanup(site, site_conf, instance_conf, dir_moves,
                           file_mods = file_mods)
    
def get_instance_configuration(context, site, site_conf, instance_conf,
                               old_instance_conf, locale, msgs):
    instance = dl.dsp_create_instance(instance_conf['shortname'],
                                      instance_conf['version'])
    if context == dl.CONTEXT_UPGRADE:
        #and \
        #instance_conf['version'] != old_instance_conf['version']:
        # We need to be able to log in so that we can do the
        # upgrade, so expose these options.
        for option in instance['options']:
            if option['name'] == 'instance_admin' or \
               option['name'] == 'instance_pass1':
                option['upgrade'] = 1
    dl.dsp_fill_instance(context, instance, site, site_conf,
                         instance_conf, old_instance_conf,
                         ['dbname', 'username', 'url_net', 'url_path',
                          'domain_to_path', 'instance_admin_email'])
    dl.enable_patches(instance, instance_patches)
        
    return instance

def regression_test(action, index, test_data):
    if 'url_loc_modified' not in test_data:
        test_data['url_loc'] = test_data['url_loc'] + '/lists/admin/'
        test_data['url_loc_modified'] = 1
    return dl.regression_check_index(action, index, test_data,
                                     'This document requires you to log in')
